@@ -36,24 +36,36 @@ from pathlib import Path
 import ctypes
 import functools
 
-from pymodaq.daq_utils import daq_utils as utils
-
-logger = utils.set_logger(utils.get_module_name(__file__))
+from pymodaq.utils import daq_utils as utils
+from pymodaq.utils.logger import set_logger, get_module_name
+logger = set_logger(get_module_name(__file__))
 if utils.is_64bits():
     path_dll = str(Path(os.environ['VXIPNPPATH64']).joinpath('Win64', 'Bin'))
 else:
     path_dll = str(Path(os.environ['VXIPNPPATH']).joinpath('WinNT', 'Bin'))
 os.add_dll_directory(path_dll)
 
-try:
-    path_python_wrapper = Path(os.environ['VXIPNPPATH']).joinpath('WinNT', 'TLPM', 'Example', 'Python')
-    sys.path.insert(0, str(path_python_wrapper))
-    import TLPM
-except ModuleNotFoundError as e:
-    error = f"The *TLPM.py* python wrapper of thorlabs TLPM dll could not be located on your system. Check if present" \
-            f" in {path_dll}"
-    raise ModuleNotFoundError(error)
 
+def tlpm_path(tlpm: Path):
+    return Path(os.environ['VXIPNPPATH']).joinpath('WinNT', 'TLPM', tlpm, 'Python')
+
+
+module_error = True
+for example_str in ['Example', 'Examples']:
+    try:
+        path_python_wrapper = tlpm_path(example_str)
+        sys.path.insert(0, str(path_python_wrapper))
+        import TLPM
+        module_error = False
+        break
+    except ModuleNotFoundError as e:
+        pass
+if module_error:
+    error = f"The *TLPM.py* python wrapper of thorlabs TLPM dll could not be located on your system. Check if present"\
+            f" in one of these path:\n"\
+            f"{tlpm_path('Example')}\n"\
+            f"{tlpm_path('Examples')}"
+    raise ModuleNotFoundError(error)
 
 def error_handling(default_arg=None):
     """decorator around TLPM functions to handle return if errors"""
@@ -195,11 +207,15 @@ class CustomTLPM:
 
 
 if __name__ == '__main__':
+    from time import sleep
     print(Ndevices)
     print(DEVICE_NAMES)
 
     with CustomTLPM(0) as tlpm:
-        tlpm.wavelength
-        tlpm.get_power()
+        print(tlpm.wavelength)
+        tlpm.wavelength = 532.
+        sleep(1)
+        print(tlpm.wavelength)
+        print(tlpm.get_power())
 
 
